/*
 * Copyright(C) OASIS(R) 2005,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.
 */
package org.oasisopen.sca;

import javax.security.auth.Subject;

/**
 * The following shows the RequestContext interface.
 */
public interface RequestContext {

    /**
     * Returns the JAAS Subject of the current request.
     * 
     * @return The JAAS Subject of the current request
     */
    Subject getSecuritySubject();
    
    /**
     * Returns the name of the service on the Java implementation the
     * request came in on.
     * 
     * @return the name of the service on the Java implementation the
     * request came in on
     */
    String getServiceName();

    /**
     * Returns a service reference to the callback as specified by the
     * caller. This method returns null when called for a service
     * request whose interface is not bidirectional or when called for
     * a callback request.
     * 
     * @param     <CB> the type of the callback reference
     * @return    a service reference to the callback as specified by
     *            the caller
     */
    <CB> ServiceReference<CB> getCallbackReference();

    /**
     * Returns a proxy for the callback as specified by the caller.
     * Similar to the getCallbackReference() method, this method returns
     * null when called for a service request whose interface is not
     * bidirectional or when called for a callback request.
     * 
     * @param     <CB> the type of the callback proxy
     * @return    a proxy for the callback as specified by the caller
     */
    <CB> CB getCallback();

    /**
     * When invoked during the execution of a service operation, this
     * method MUST return a ServiceReference that represents the service
     * that was invoked. When invoked during the execution of a callback
     * operation, this method MUST return a ServiceReference that
     * represents the callback that was invoked.
     * 
     * @param     <B> the type of the service reference
     * @return    the ServiceReference representing the service or callback
     *            that was invoked
     */
    <B> ServiceReference<B> getServiceReference();
}
